[Bug tree-optimization/18557] Inefficient code generated by -ftree-vectorize on Alpha
falk at debian dot org
gcc-bugzilla@gcc.gnu.org
Fri Nov 19 11:29:00 GMT 2004
------- Additional Comments From falk at debian dot org 2004-11-19 11:29 -------
(In reply to comment #3)
> Can we get some numbers to understand how worse we are behaving?
The code size is inflated by a factor of about 3. Run time difference depends
a lot on how many bytes are actually copied, how predictable the branches are
etc. If I just run the test case on always the same data, which is about the
best possible case, the vectorized code is 5% slower than f2.
--
http://gcc.gnu.org/bugzilla/show_bug.cgi?id=18557
More information about the Gcc-bugs
mailing list